﻿using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.UI;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Documents;
using Windows.UI.Xaml.Media;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "RichTextBlock 엘리먼트 : TextHighlighters 속성 사용하기";

            #endregion
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 텍스트 하이라이트 색상 콤보 박스 선택 변경시 처리하기 - textHighlightColorCombobox_SelectionChanged(sender, e)

        /// <summary>
        /// 텍스트 하이라이트 색상 콤보 박스 선택 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void textHighlightColorCombobox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            ComboBox comboBox = sender as ComboBox;

            ComboBoxItem item = comboBox.SelectedItem as ComboBoxItem;

            Color color = Colors.Yellow;

            switch(item.Content as string)
            {
                case "Yellow" : color = Colors.Yellow; break;
                case "Red"    : color = Colors.Red;    break;
                case "Blue"   : color = Colors.Blue;   break;
            }

            TextRange textRange = new TextRange()
            {
                StartIndex = 28,
                Length     = 11
            };

            TextHighlighter textHighlighter = new TextHighlighter()
            {
                Background = new SolidColorBrush(color),
                Ranges     = { textRange }
            };

            this.richTextBlock.TextHighlighters.Clear();

            this.richTextBlock.TextHighlighters.Add(textHighlighter);
        }

        #endregion
    }
}